
import sys
from read_utils import *
import pandas as pd

def main():
    #Argument parsing:
    if len(sys.argv) < 2:
        print(f"Usage: {sys.argv[0]} <root rundir>")
        print(f"Usage: {sys.argv[0]} dir1 [dir2] [dir3]")
        sys.exit(1)

    # Search for rundirs:
    rundirs = []
    for root_rundir_arg in sys.argv[1:]:
        rundir.extend(find_rundirs_folders(root_rundir_arg))
    
    rundirs = sorted(rundirs)

    # Get exec time:
    elap_time_list = []
    cpu_time_list = []
    for rundir in rundirs:
        ts_completed = get_timesteps(rundir)
        print(f"Found rundir at {rundir} with {ts_completed} timesteps")

        elap_time, cpu_time = get_execution_time(rundir)
        if elap_time is not None and cpu_time is not None:
            elap_time_list.append(float(elap_time))
            cpu_time_list.append(float(cpu_time))
        else:
            elap_time_list.append(None)
            cpu_time_list.append(None)
        print(f"{elap_time} {cpu_time} (s)")

    df = pd.DataFrame({
        "rundir" : rundirs,
        "elap_time" : elap_time_list,
        "cpu_time" : cpu_time_list
    })
 
    df['cpu_per_elap'] = df['cpu_time'] / df['elap_time']
    min_elap_time = df['elap_time'].max()
    df['speedup'] = min_elap_time / df['elap_time']
    df['sp-perc'] = ((min_elap_time / df['elap_time']) - 1 ) * 100
    print(df)

    # Print results with csv:
    df.to_csv("output.csv", index=False)

if __name__ == "__main__":
    main()
